@@ -41,7 +41,9 @@ class GrimoirePage:
         return self.__get_directives_class().keys()
 
     def __get_directives_class(self) -> [Plugin]:
-        return [DNSChecker, DNSLookup, SSLVerify]
+        directive = [DNSChecker, DNSLookup, SSLVerify]
+        # TODO Add reader from folder
+        return directive
 
     def __get_directives_str(self) -> [str]:
         """
@@ -59,7 +61,7 @@ class GrimoirePage:
         """
         try:
             return self.data["server"].keys()
-        except:
+        except Exception:
             return []
 
     def run(self, command=None, url=None):
@@ -81,7 +83,9 @@ class GrimoirePage:
         for url in url_to_run:
             for command in command_to_run:
                 cl = map_command[command]()
-                async_result = pool.apply_async(cl.execute, (command, self.data["server"][url]))
+                async_result = pool.apply_async(
+                    cl.execute, (command, self.data["server"][url])
+                )
                 return_val = async_result.get()
                 self.data["server"][url][command] = return_val
 
@@ -118,21 +122,27 @@ class GrimoirePage:
                 except AttributeError:
                     printable_error[command] = errors
                 for key in all.keys():
-                    printable[command][key] = printable[command].get(key, 0) + int(
-                        all[key]
-                    )
+                    printable[command][key] = printable[command].get(
+                        key, 0
+                    ) + int(all[key])
 
         for command in printable.keys():
             message = [(k, v) for k, v in printable[command].items()]
             try:
-                message_error = [(k, v) for k, v in printable_error[command].items()]
+                message_error = [
+                    (k, v) for k, v in printable_error[command].items()
+                ]
             except AttributeError:
                 message_error = []
             head = [command, ""]
             if len(message) > 0:
                 print(tabulate(message, head, tablefmt="pipe"))
             if len(message_error) > 0:
-                print(tabulate(message_error, ["domain", "message"], tablefmt="pipe"))
+                print(
+                    tabulate(
+                        message_error, ["domain", "message"], tablefmt="pipe"
+                    )
+                )
             print()
 
     def info(self, command=None, url=None) -> None:
