@@ -57,7 +57,9 @@ class ConfigManager:
 
     @data_path.getter
     def data_path(self):
-        return self.config.get("data_path", Path.home() / ".servergrimoire/data")
+        return self.config.get(
+            "data_path", Path.home() / ".servergrimoire/data"
+        )
 
     @property
     def logger_level(self):
